@@ -14,5 +14,5 @@ $_logo=0; # enable logo
 $_toptitle=0; # old-style title.
 
 $imgdir=$themeurl."/imgs";
-#$icon['rss']="<img src='$imgdir/feed.png' alt='RSS' style='vertical-align:middle;border:0px' />";
+$icon['rss']="<img src='$imgdir/feed.png' alt='RSS' style='vertical-align:middle;border:0px' />";
 ?>
